@@ -13,7 +13,7 @@ from numpy.ma import array      as numpy_ma_array
 from numpy.ma import is_masked  as numpy_ma_is_masked
 from numpy.ma import masked_all as numpy_ma_masked_all
 
-from ..functions import parse_indices, get_subspace, abspath
+from ..functions import parse_indices, get_subspace #, abspath
 from ..functions import inspect as cf_inspect
 from ..constants import CONSTANTS
 
@@ -303,9 +303,9 @@ A sub-array stored in a file.
 '''
         self.__dict__ = kwargs
 
-        f = getattr(self, 'file', None)
-        if f is not None:
-            self.file = abspath(f)
+#        f = getattr(self, 'file', None)
+#        if f is not None:
+#            self.file = abspath(f)
     #--- End: def
             
     def __deepcopy__(self, memo):
