@@ -203,6 +203,9 @@ data array
 ...               Units      = cf.Units('K'))
 
 '''
+
+        self._subarray  = None
+        
         self.axes      = axes      # DO NOT UPDATE INPLACE
         self.flip      = flip      # DO NOT UPDATE INPLACE
         self.part      = part      # DO NOT UPDATE INPLACE
@@ -239,7 +242,8 @@ If the partition contains a non-temporary file which is not referenced
 by any other partition then the file is closed.
 
         '''
-        subarray = getattr(self, '_subarray', None)
+#        subarray = getattr(self, '_subarray', None)
+        subarray = self._subarray
         
         # If the subarray is unique it will have 2 references to
         # it plus 1 within this method, making 3. If it has more
@@ -341,7 +345,9 @@ temporary FileArray.
     `None`
 
         '''
-        subarray = getattr(self, '_subarray', None)
+#        subarray = getattr(self, '_subarray', None)
+        subarray = self._subarray
+        
         if subarray is None:
             return
         
@@ -353,12 +359,16 @@ temporary FileArray.
                     return
 
                 file_counter = self.file_counter
-                count = file_counter.get(filename, 0)
-                file_counter[filename] = count + i
-                if file_counter[filename] <= 0:
+#                count = file_counter.get(filename, 0)
+#                file_counter[filename] = count + i
+#                if file_counter[filename] <= 0:
+                count = file_counter.get(filename, 0) + i
+                if count <= 0:
                     # Remove the file from the dictionary if its count has
                     # dropped to zero
-                    del file_counter[filename]
+                    file_counter.pop(filename, None)
+                else:
+                    file_counter[filename] = count
         except:
             # If we're here then it is likely that FileArray has been
             # torn down, so just do nothing.
@@ -746,12 +756,12 @@ values of the partition's `!_original` attribute and on the
 >>> p.array(...)
 >>> p.close()
 
-        '''
+        '''        
         config = getattr(self, 'config', None)
         
         if config is None:
             return
-        
+#        print 'close:', hasattr(self, 'config'),
         if kwargs:
             config.update(kwargs)
 
@@ -912,7 +922,11 @@ values of the partition's `!_original` attribute and on the
 #        if hasattr(self, '_original'):
 #            del self._original
 
-        del self.config
+#        print hasattr(self, 'config'),
+        try:
+            del self.config
+        except AttributeError:
+            pass
     #--- End: def
 
     def copy(self):
@@ -969,12 +983,9 @@ otherwise a memory leak could occur. For example:
 >>>  
 
 '''
-#        _debug = True
         config = self.config
 
         unique_array = config['unique_subarray']
-#        if _debug:
-#            print '    unique_array =', unique_array, self._subarray
             
         p_axes   = self.axes
         p_flip   = self.flip
@@ -985,9 +996,6 @@ otherwise a memory leak could occur. For example:
         p_location = self.location
         subarray = self._subarray
 
-#        if _debug:
-#            print '    id(subarray) =', id(subarray)
-            
         len_p_axes = len(p_axes)
 
         if not self.in_memory:
@@ -1139,14 +1147,6 @@ otherwise a memory leak could occur. For example:
                     if not masked:
                         p_data = p_data.view(numpy_ma_MaskedArray)
                         masked = True
-      #              print '-------------------'
-     #               print type(p_data.mask), type(mask)
-    #                print p_data.mask
-   #                 print mask
-  #                  print '-------------------'
-#                    kk = (mask | p_data.mask).array
- #                   print kk
- #                   print 'type kk=', type(kk)
  
                     p_data.mask = (mask | p_data.mask).array
             #--- End: for
@@ -1208,9 +1208,6 @@ otherwise a memory leak could occur. For example:
             self._in_place_changes = in_place_changes
         #--- End: if
 
-#        if _debug:
-#            print '      id(p_data) =', id(p_data)
-
         # ------------------------------------------------------------
         # Return the numpy array
         # ------------------------------------------------------------
