@@ -1,6 +1,6 @@
 from .netcdf.write import write as netcdf_write
 
-def write(fields, filename, fmt='NETCDF3_CLASSIC', overwrite=True,
+def write(fields, filename, fmt='NETCDF4', overwrite=True,
           verbose=False, cfa_options=None, mode='w',
           least_significant_digit=None, endian='native', compress=0,
           fletcher32=False, no_shuffle=False, datatype=None,
@@ -10,10 +10,10 @@ def write(fields, filename, fmt='NETCDF3_CLASSIC', overwrite=True,
     '''Write fields to a netCDF file.
     
 NetCDF dimension and variable names will be taken, if present, from
-variables' `~Variable.ncvar` attributes and the domain axis
-`~DomainAxis.ncdim` attributes, otherwise they are inferred from
-standard names or set to defaults. NetCDF names may be automatically
-given a numerical suffix to avoid duplication.
+variables' `!ncvar` attributes and the domain axis `!ncdim`
+attributes, otherwise they are inferred from standard names or set to
+defaults. NetCDF names may be automatically given a numerical suffix
+to avoid duplication.
 
 Output netCDF file global properties are those which occur in the set
 of CF global properties and non-standard data variable properties and
@@ -21,6 +21,10 @@ which have equal values across all input fields.
 
 .. seealso:: `cf.read`
 
+:Examples 1:
+
+>>> cf.write(f, new_file.nc')
+
 :Parameters:
 
     fields: (arbitrarily nested sequence of) `cf.Field` or `cf.FieldList`
@@ -54,19 +58,57 @@ which have equal values across all input fields.
     fmt: `str`, optional
         The format of the output file. One of:
 
-           =====================  ================================================
-           fmt                    Description
-           =====================  ================================================
-           ``'NETCDF3_CLASSIC'``  Output to a CF-netCDF3 classic format file     
-           ``'NETCDF3_64BIT'``    Output to a CF-netCDF3 64-bit offset format file 
-           ``'NETCDF4_CLASSIC'``  Output to a CF-netCDF4 classic format file      
-           ``'NETCDF4'``          Output to a CF-netCDF4 format file              
-           ``'CFA3'``             Output to a CFA-netCDF3 classic format file 
-           ``'CFA4'``             Output to a CFA-netCDF4 format file 
-           =====================  ================================================
+           ==========================  ===============================
+           *fmt*                       Output file type
+           ==========================  ===============================
+           ``'NETCDF4'``               NetCDF4 format file. This is
+                                       the default.       
+    
+           ``'NETCDF4_CLASSIC'``       NetCDF4 classic format file
+                                       (see below) 
+    
+           ``'NETCDF3_CLASSIC'``       NetCDF3 classic format file
+                                       (limited to file sizes less
+                                       than 2 Gb).
 
-        By default the *fmt* is ``'NETCDF3_CLASSIC'``. Note that the
-        netCDF3 formats may be slower than any of the other options.
+           ``'NETCDF3_64BIT_OFFSET'``  NetCDF3 64-bit offset format
+                                       file
+
+           ``'NETCDF3_64BIT_DATA'``    NetCDF3 64-bit offset format
+                                       file with extensions (see
+                                       below)
+
+           ``'NETCDF3_64BIT'``         An alias for
+                                       ``'NETCDF3_64BIT_OFFSET'``
+
+           ``'CFA3'``                  CFA-netCDF3 classic format file 
+
+           ``'CFA4'``                  CFA-netCDF4 format file 
+           ==========================  ===============================
+
+
+        By default the format is ``'NETCDF4'``.
+
+        Note that the netCDF3 formats may be considerably slower than
+        any of the other options.
+
+        All formats support large files (i.e. those greater than 2 Gb)
+        except ``'NETCDF3_CLASSIC'``.
+
+        ``'NETCDF3_64BIT_DATA'`` is a format that requires version
+        4.4.0 or newer of the C library (use `cf.environment` to see
+        which version if the netCDF-C library is in use). It extends
+        the ``'NETCDF3_64BIT_OFFSET'`` binary format to allow for
+        unsigned/64 bit integer data types and 64-bit dimension sizes.
+
+        ``'NETCDF4_CLASSIC'`` files use the version 4 disk format
+        (HDF5), but omits features not found in the version 3
+        API. They can be read by HDF5 clients. They can also be read
+        by netCDF 3 clients only if they have been relinked against
+        the netCDF4 library.
+
+        ``'NETCDF4'`` files use the version 4 disk format (HDF5) and
+        use the new features of the version 4 API.
 
     overwrite: `bool`, optional
         If False then raise an exception if the output file
@@ -155,7 +197,8 @@ which have equal values across all input fields.
         remain unchanged. By default, input data types are
         preserved. Data types defined by `numpy.dtype` objects in a
         dictionary whose are input data types with values of output
-        data types.
+        data types. Note that data arrays of coordinates and other
+        metadata may also be converted.
 
           *Example:*
             To convert 64-bit floats and 64-bit integers to their
@@ -163,7 +206,7 @@ which have equal values across all input fields.
             numpy.dtype('float32'), numpy.dtype('int64'):
             numpy.dtype('int32')}``.
        
-   single: `bool`, optional
+    single: `bool`, optional
         Write 64-bit floats as 32-bit floats and 64-bit integers as
         32-bit integers. By default, input data types are
         preserved. Note that ``single=True`` is exactly equivalent to
@@ -214,33 +257,18 @@ which have equal values across all input fields.
         users will read from the file.
 
     unlimited: sequence of `str`, optional
-        Create a unlimited dimensions (dimensions that can be appended
+        Create unlimited dimensions (dimensions that can be appended
         to). A dimension is identified by either a standard name; one
         of T, Z, Y, X denoting time, height or horixontal axes
         repsectively (as defined by the CF conventions); or the value
         of an arbitrary CF property preceeded by the property name and
-        a colon. For example:
-
-         Multiple unlimited axes may be defined by specifying more
-         than one --unlimited option. Note, however, that only netCDF4
-         formats support multiple unlimited dimensions. For example,
-         to set the time and Z dimensions to be unlimited you could
-         use unlim- ited=time --unlimited=Z
-ALERT
-              An example of defining an axis by an arbitrary CF property could
-              be --unlimited=long_name:pseudo_level
-ALERT
+        a colon.
 
 :Returns:
 
     `None`
 
-:Raises:
-
-    IOError:
-        If *overwrite* is False and the output file pre-exists.
-
-:Examples:
+:Examples 2:
 
 >>> f
 [<CF Field: air_pressure(30, 24)>,
@@ -249,10 +277,6 @@ ALERT
  <CF Field: potential_temperature(19, 30, 24)>]
 >>> write(f, 'file')
 
->>> type(f)
-<class 'cf.field.FieldList'>
->>> type(g)
-<class 'cf.field.Field'>
 >>> cf.write([f, g], 'file.nc', verbose=True)
 [<CF Field: air_pressure(30, 24)>,
  <CF Field: u_compnt_of_wind(19, 29, 24)>,
